%%%A script file for generating generate data (Beverton-Holt),which was 
%used in the paper "A semiparametric Bayesian approach to estimating maximum 
%reproductive rates at low population sizes" (M.Sugeno and S.B. Munch).

%%%Inputs:
%v:noise level in data(can be between 0.1 and 1).
%smin:minimum stock size in data(can be between 0 and 0.34).

%%%Constants used in the paper
%a:slope at the origin alpha,which is 4 in the analysis (In MCMC
%routine,log(alpha),not alpha,is estimated).
%n:sample size in data(n=30 in the paper).
%srange:range of stock size used for generating recruitment data

%%%Outputs (stored in MAT-file 'test_data'):
%s:stock data
%r:recruitment data
%st:grid for stock
%rt:true recruitment based on 'st'
%a:true slope at the origin
%b:true 'beta' in the Ricker model
%v:true noise level

%%%Codes begins from here
clear all;close all;

%Constants that are manipulated in the analysis
v=0.1;%can be between 0.1 and 1
smin=0;%can be between 0 and 0.34

%Constants used in generating data
a=4;
srange=1.02;
n=30;

%Name of data
na='test_data';

%Scaling the parameter b in the BH model(this choise allows true maximum recruitment to be 1)
b=a;

%Generating stock data(with noise)                
s=smin+srange*rand(n,1);
r=a*s./(1+b*s).*exp(v^(1/2)*randn(n,1));

%True data-generating function
st=linspace(0.0001,max(s),100)';
rt=a*st./(1+b*st);

%Plotting the data and the function in s-log(r/s)
plot(s,log(r./s),'bO');xlabel('S');hold on;
plot(st,log(rt./st),'b');ylabel('ln(R/S)');hold on;

%Saving data
save(na,'s','r','st','rt','a','b','v') ;