%%%A script file for generating generate data (Saila-Lorda),which was 
%used in the paper "A semiparametric Bayesian approach to estimating maximum 
%reproductive rates at low population sizes" (M.Sugeno and S.B. Munch).


%v:noise level in data(can be between 0.1 and 1)
%smin:minimum stock size in data(can be between 0 and 0.34)
%a:slope at the origin alpha,which is 11.5416 in the analysis (In MCMC routine,log(alpha),not alpha,is estimated)
%b:strenght of density dependence,which is 2.5330 in the analysis
%c:strength of depensation,which is 2 in the analyses
%n:sample size in data(n=30 in the paper)

%%%Inputs:
%v:noise level in data(can be between 0.1 and 1).
%smin:minimum stock size in data(can be between 0 and 0.34).

%%%Constants used in the paper
%a:a parameter in the SL model (a=11.5416).In the paper,this has little 
%to do with slope at the origin (see 'Discussion').
%b:strenght of density dependence (b=2.5330).
%c:strength of depensation (c=2).
%n:sample size in data(n=30 in the paper).
%srange:range of stock size used for generating recruitment data

%%%Outputs (stored in MAT-file 'test_data'):
%s:stock data
%r:recruitment data
%st:grid for stock
%rt:true recruitment based on 'st'
%a:a=11.5416.
%b:b=2.5330.
%c:c=2.
%v:true noise level.



%%%Codes begins from here
clear all;close all;

%Constants that are manipulated in the analysis
v=0.1;%can be between 0.1 and 1
smin=0;%can be between 0 and 0.34

%Constants used in generating data
n=30;
a=11.5416;
b=2.5330;
c=2;
srange=1.02;

%Name of data
na='test_data';

%Generating stock data(with noise)                
s=smin+srange*rand(n,1);
r=a*s.^c.*exp(-b*s).*exp(v^(1/2)*randn(n,1));

%True data-generating function
st=linspace(0.0001,max(s),100)';
rt=a*st.^c.*exp(-b*st);

%Plotting the data and the function in s-log(r/s)
plot(s,log(r./s),'bO');xlabel('S');hold on;
plot(st,log(rt./st),'b');ylabel('ln(R/S)');hold on;

%Saving data
save(na,'s','r','st','rt','a','b','c','v') ;