function[out]=Linear_MAP(pars0,pars1,pars2,pars3);
%%%Function to compute the maximum a posteriori (MAP) estimates of parameters 
%in the 'linear' model. This code is called under a code 'Linear'. The MAP 
%estimates are obtained using a matlab built-in function 'fminsearch'.

%%%Inputs:
%'pars0' is a vector collecting an initial guess for the MAP estimates of 
%the posterior distributions of the parameters in the 'lienar' model.
%'pars1' is a matrix collecting data for stock(s) standardized for data 
%analysis (data(:,1)=s/max(s)) and data for a transformed variate describing a
%stock-recruitment relationship (data(:,2)=log(r/s)),where 'r' is
%recruitment. 
%'pars2' is a vector specifying a prior distribution for 'phi'
%'pars3' is a vector specifying a prior distribution for 'tau squared'

%%%Outputs:
%'out' is a log(likelihood times prior) calculated while searching for a 
%combination of parameters in the 'linear' model that minimizes 
%log(likelihood times prior).This does not appear as an output.

%%%Description of 'Linear_MAP'.
%Changing notations of parameters.
loga=pars0(1);
logphi=pars0(2);
logtau=pars0(3);%log(tau2)
logv=pars0(4);%log(sigma2)
be=pars0(5);%beta

%Changing notations of data.
x=pars1(:,1);
y=pars1(:,2);

%Defining vectors and maxtices that are used for constructing mean and
%covariance functions in the 'linear' model.
lx=length(x);
ly=length(y);
iy=eye(ly);
xd=abs(x*ones(1,lx)-ones(lx,1)*x').^2;
xvec=x.^2;

%Constructing the covariance function.
co=exp(logtau)*exp(-exp(logphi)*xd);    
co_cond=co-exp(logtau)*exp(-exp(logphi)*xvec)*exp(-exp(logphi)*xvec');  

%Likelihood.
L=-1/2*log(det(exp(logv)*iy+co_cond))-1/2*(y-loga-be*x)'*inv(co_cond+exp(logv)*iy)*(y-loga-be*x);

%Priors (flat priors for log(alpha),beta,and log(v).Gamma priors for phi and tau2,which are rescaled in log scale). 
alpphi=pars2(1);bepphi=pars2(2);Plogphi=log((exp(logphi)).^(-alpphi).*exp(-bepphi.*(exp(logphi))));
alptau=pars3(1);beptau=pars3(2);Plogtau=log((exp(logtau)).^(-alptau).*exp(-beptau.*(exp(logtau))));
Plogv=0;
out=-(L+Plogphi+Plogtau+Plogv);