function [R]=convergence(data,direction);
%%%Function to conduct convergence diagnosis ('Bayesian data analysis' by 
%Gelman et al 2003 p.288-).
%If samples of a posterior distribution are collected in a column vector,
%use 1 for 'direction'. 
%If samples of a posterior distribution are collected in a row vector,use 0 
%for 'direction'. 
%In our study,we use a column vector for collecting samples generated from 
%a posterior distribution of the parameter in a model. Therefore,we set 1 
%for 'direction'.

%%%Inputs:
%'data' is a matrix collecting samples generated from a posterior
%distribution.
%'data(:,1)' collects samples generated from a posterior distribution,which 
%is constructed by using one of the two initial guesses of the distribution. 
%'data(:,2)' collects samples generated from a posterior distribution,which 
%is constructed by using the other initial guess of the distribution. 

%%%Outputs:
%'R' is a vector of statistics used for the diagnosis

%%%Setting up the diagnosis
y=data;
lx=max(size(y));%sample size
m=min(size(y));%number of pararel runs
switch direction
    case 1
        B=lx/(m-1)*sum((mean(y)-mean(mean(y))).^2);
        W=1/m*sum(var(y));
        V=(lx-1)/lx*W+1/lx*B;
        R=sqrt(V/W);
    case 0
        B=lx/(m-1)*sum((mean(y,2)-mean(mean(y,2))).^2);
        W=1/m*sum(var(y'));
        V=(lx-1)/lx*W+1/lx*B;
        R=sqrt(V/W);
end