function[xgrid,xpdf]=pdf(c_global,c_local,inc,xvar,xcond,mle,s,r);
%%%Function to construct a probability density function which is used under a 
%function 'ricker_loga':

%%%Inputs:
%'c_global' is used for determining range of 'log(alpha)' and 'beta' at 
%which a probability density is calculated. This range is determine by 
%comparing a probability density to the maximum probability.
%'c_local' is used for determining a grid of 'beta'. The grid is used for 
%marginalizing 'beta' out to obtain a probability density of 'log(alpha)'.
%'inc_up' is used for determining a grid of 'log(alpha)' in a positive 
%direction. 
%'inc_down' is used for determining a grid of 'log(alpha)' in a positive
%direction.
%'xvar' is a MAP estimate of 'beta'.
%'xcond' is a MAP estimate of 'log(alpha)'.
%'mle' is the maximum probability density.
%'s' is a data for stock
%'r' is a data for recruitment

%%%Outputs:
%'xgrid' is a vector collecting specific values that were used for computing 
%the probability density density.
%'xpdf' is a vector collecting specific values of a probability density
%function that are evaluated at 'xgrid'.

%%%Function begins from here:
%'x' is a vector collecting left and right sides of a bin representing a 
%probability density. The mid point of the sides of a bin is used as a 
%specific value at which a probability density is computed.
x(1,1)=xvar;

%'like_old' is a reference probability density to which a new probability 
%density is evaluated.
like_old=mle;
%'x_old' is a MAP estimate of 'beta' at specific value of 'log(alpha)'.
x_old=xvar;

%Loops for constructing a probability density function given 'log(alpha)'.
count=0;
step=1;
ratio_local=0;
ratio_global=1;
%This loop ends when a probability density evaluated at a specific value of
%'beta' given 'log(alpha)' becomes less than 0.01 of the maximum probability
%density (indicated with 'ratio_global').
while ratio_global>c_global;
    %This loop is used for determining a next 'beta' at which a probability 
    %density is evaluated. In our case, a next 'beta' is accepted when the 
    %probability density is not smaller than 0.75 (given with 'c_local') 
    %of the previous probability density.    
    while ratio_local<c_local;
        %Generating a next 'beta' using some increment 'inc'.
        switch count
            case 0
                %The first proposed next 'beta'.
                x_new=x_old+inc;
            otherwise
                %Shrinking the increment till the 0.75 criterion is met.
                x_new=1/2*(x_new+x_old);
        end
        %Computing the probability density evaluated at a new 'beta' given
        %'log(alpha)'.
        like_new=ricker2([xcond,x_new],s,r);
        count=count+1;
        ratio_local=like_new/like_old;
    end      
    %Using the grid for 'beta', we calcualte the probability density using
    %the Simpson's rule ('integral').
    fold=like_old;
    fnew=like_new;
    fmid=ricker2([xcond,1/2*(x_old+x_new)],s,r);
    integral(step,1)=1/6*abs(x_new-x_old)*(fold+4*fmid+fnew);
    
    %Updating values.
    step=step+1;     
    x(step,1)=x_new; 
    like_old=like_new;     
    x_old=x_new;
    ratio_global=like_old/mle;  
    count=0; 
    ratio_local=0;
end

%Summarizing results.
xgrid=1/2*(x(1:end-1,1)+x(2:end));
xpdf=integral;